@@ -4,6 +4,8 @@ from py42._internal.compat import str
 from py42.clients import BaseClient
 from py42.clients.util import get_all_pages
 
+from py42.sdk.queries.query_filter import create_eq_filter_group
+
 
 class AlertClient(BaseClient):
     _uri_prefix = u"/svc/api/v1/{0}"
@@ -18,7 +20,7 @@ class AlertClient(BaseClient):
         return self._session.post(uri, data=query)
 
     def get_details(self, alert_ids, tenant_id=None):
-        if type(alert_ids) is not list:
+        if not isinstance(alert_ids, (list, tuple)):
             alert_ids = [alert_ids]
         tenant_id = tenant_id if tenant_id else self._user_context.get_current_tenant_id()
         uri = self._uri_prefix.format(u"query-details")
@@ -27,7 +29,7 @@ class AlertClient(BaseClient):
         return _convert_observation_json_strings_to_objects(results)
 
     def resolve(self, alert_ids, tenant_id=None, reason=None):
-        if type(alert_ids) is not list:
+        if not isinstance(alert_ids, (list, tuple)):
             alert_ids = [alert_ids]
         tenant_id = tenant_id if tenant_id else self._user_context.get_current_tenant_id()
         reason = reason if reason else u""
@@ -36,7 +38,7 @@ class AlertClient(BaseClient):
         return self._session.post(uri, data=json.dumps(data))
 
     def reopen(self, alert_ids, tenant_id=None, reason=None):
-        if type(alert_ids) is not list:
+        if not isinstance(alert_ids, (list, tuple)):
             alert_ids = [alert_ids]
         tenant_id = tenant_id if tenant_id else self._user_context.get_current_tenant_id()
         uri = self._uri_prefix.format(u"reopen-alert")
@@ -53,11 +55,17 @@ class AlertClient(BaseClient):
             return str(query)
 
     def _get_alert_rules(
-        self, tenant_id, sort_key=None, sort_direction=None, page_num=None, page_size=None
+        self,
+        tenant_id,
+        groups=None,
+        sort_key=None,
+        sort_direction=None,
+        page_num=None,
+        page_size=None,
     ):
         data = {
             u"tenantId": tenant_id,
-            u"groups": [],
+            u"groups": groups or [],
             u"groupClause": u"AND",
             u"pgNum": page_num - 1,  # Minus 1, as this API expects first page to start with zero.
             u"pgSize": page_size,
@@ -73,19 +81,33 @@ class AlertClient(BaseClient):
             self._get_alert_rules,
             u"ruleMetadata",
             tenant_id=tenant_id,
+            groups=None,
             sort_key=sort_key,
             sort_direction=sort_direction,
         )
 
-    def get_rules_by_name(self, rule_name):
-        rule_pages = self.get_all_rules()
-        matched_rules = []
-        for rule_page in rule_pages:
-            rules = rule_page[u"ruleMetadata"]
-            for rule in rules:
-                if rule_name.lower() == rule[u"name"].lower():
-                    matched_rules.append(rule)
-        return matched_rules
+    def get_all_rules_by_name(self, rule_name, sort_key=u"CreatedAt", sort_direction=u"DESC"):
+        tenant_id = self._user_context.get_current_tenant_id()
+        return get_all_pages(
+            self._get_alert_rules,
+            u"ruleMetadata",
+            tenant_id=tenant_id,
+            groups=[json.loads(str(create_eq_filter_group(u"Name", rule_name)))],
+            sort_key=sort_key,
+            sort_direction=sort_direction,
+        )
+
+    def get_rule_by_observer_id(self, observer_id, sort_key=u"CreatedAt", sort_direction=u"DESC"):
+        tenant_id = self._user_context.get_current_tenant_id()
+        results = get_all_pages(
+            self._get_alert_rules,
+            u"ruleMetadata",
+            tenant_id=tenant_id,
+            groups=[json.loads(str(create_eq_filter_group(u"ObserverRuleId", observer_id)))],
+            sort_key=sort_key,
+            sort_direction=sort_direction,
+        )
+        return next(results)
 
 
 def _convert_observation_json_strings_to_objects(results):
